@@ -26,12 +26,13 @@
 #  $Id$
 #
 
-=pod 
-=item NAME
+=pod
 
-A Prima example launcher
+=head1 NAME
 
-=item FEATURES
+examples/launch.pl - A Prima example launcher
+
+=head1 FEATURES
 
 Uses to execute several Prima examples in one task space.
 Many examples inflict the view af a user-selected widget, but
@@ -40,6 +41,9 @@ such experiments. See cv.pl or fontdlg.pl in particular.
 
 =cut
 
+use strict;
+use warnings;
+
 use Prima;
 use Prima::Classes;
 use Prima::StdDlg;
